@@ -118,11 +118,10 @@ class LoggingSetup:
             logger.addHandler(handler)
 
         if self.smtp_log or "SMTP_LOG" in os.environ:
-            if "SMTP_LOG_ADDRESS" in os.environ:
-                parts = os.environ["SMTP_LOG_ADDRESS"].split(":")
+            address = os.environ["SMTP_LOG_ADDRESS"] if "SMTP_LOG_ADDRESS" in os.environ else self.smtp_log_address
+            if isinstance(address, str):
+                parts = address.split(":")
                 address = (parts[0], parts[1] if len(parts) > 1 else 25)
-            else:
-                address = self.smtp_log_address
 
             sender = os.environ["SMTP_LOG_SENDER"] if "SMTP_LOG_SENDER" in os.environ else self.smtp_log_sender
             if not sender:
